@@ -46,6 +46,32 @@ class RepeatedTimer(object):
         self.is_running = False
 
 
+class RepeatedTimer(object):
+    def __init__(self, interval, function, *args, **kwargs):
+        self._timer = None
+        self.interval = interval
+        self.function = function
+        self.args = args
+        self.kwargs = kwargs
+        self.is_running = False
+        self.start()
+
+    def _run(self):
+        self.is_running = False
+        self.start()
+        self.function(*self.args, **self.kwargs)
+
+    def start(self):
+        if not self.is_running:
+            self._timer = Timer(self.interval, self._run)
+            self._timer.start()
+            self.is_running = True
+
+    def stop(self):
+        self._timer.cancel()
+        self.is_running = False
+
+
 class OptimizationCockpit:
     """ Class displaying and refreshing the optimization cockpit.
 
@@ -65,7 +91,9 @@ class OptimizationCockpit:
         :param block_inputs: a list of block definitions of a coil
         :param cadata: a CableDatabase instance
         """
-        self.gen_opt = RoxieGeneticOptimization(config=config, optim_input_df=optim_input_df)
+        self.gen_opt = RoxieGeneticOptimization(config=config,
+                                                design_variables_df=optim_input_df,
+                                                block_inputs=block_inputs)
         self.logger_abs_path = logger_abs_path
         self.logger_df = pd.read_csv(self.logger_abs_path, index_col=0)
         self.config = config
@@ -84,7 +112,6 @@ class OptimizationCockpit:
                                                     self.logger_df,
                                                     self.config,
                                                     self.optim_input_df,
-                                                    self.block_inputs,
                                                     self.cadata)
 
             self.widget.build()
