@@ -424,14 +424,14 @@ class CosThetaGeometryTest(unittest.TestCase):
         geometry.plot_blocks()
 
         # assert
-        self.assertEqual(False, geometry.is_outside_of_first_quadrant())
+        self.assertFalse(geometry.is_outside_of_first_quadrant())
 
         # assert
         if mock_show is not None:
             mock_show.assert_called()
 
     @patch("matplotlib.pyplot.show")
-    def test_check_geometry_consistency_first_quadrant_fail(self, mock_show=None):
+    def test_check_geometry_consistency_first_quadrant_pass(self, mock_show=None):
         # arrange
         blocks_def = [{'no': 1, 'radius': 25.0, 'alpha': 0, 'phi': 0.57294, 'nco': 4, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1},
@@ -467,7 +467,26 @@ class CosThetaGeometryTest(unittest.TestCase):
         geometry.plot_blocks()
 
         # assert
-        self.assertEqual(True, geometry.is_outside_of_first_quadrant())
+        self.assertFalse(geometry.is_outside_of_first_quadrant())
+
+        # assert
+        if mock_show is not None:
+            mock_show.assert_called()
+
+    @patch("matplotlib.pyplot.show")
+    def test_check_geometry_consistency_first_quadrant_sm_ct_fail(self, mock_show=None):
+        # arrange
+        json_path = create_resources_file_path('resources/geometry/roxie/SM_CT/SM_CT_rel.json')
+        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata = CableDatabase.read_cadata(cadata_path)
+
+        # act
+        geometry = GeometryFactory.init_with_json(json_path, cadata)
+        geometry.build_blocks()
+        geometry.plot_blocks()
+
+        # assert
+        self.assertFalse(geometry.is_outside_of_first_quadrant())
 
         # assert
         if mock_show is not None:
@@ -513,7 +532,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         is_wedge_tip_too_sharp = geometry.is_wedge_tip_too_sharp(min_value_in_mm=5)
 
         # check if a wedge is not too sharp
-        self.assertEqual(True, is_wedge_tip_too_sharp)
+        self.assertTrue(is_wedge_tip_too_sharp)
 
         # assert
         if mock_show is not None:
@@ -555,7 +574,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         geometry.plot_blocks()
 
         # assert
-        self.assertEqual(False, geometry.are_turns_overlapping())
+        self.assertFalse(geometry.are_turns_overlapping())
 
         # assert
         if mock_show is not None:
@@ -598,7 +617,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         geometry.plot_blocks()
 
         # assert
-        self.assertEqual(True, geometry.are_turns_overlapping())
+        self.assertTrue(geometry.are_turns_overlapping())
 
         # assert
         if mock_show is not None:
